@@ -4,6 +4,53 @@ include("../../../common/common_rootfind_testing.jl")
 
 end
 
+@testitem "Eisenstadt-Walker Newton-Krylov" setup=[CoreRootfindTesting] tags=[:core] begin
+    using LinearAlgebra, Random, LinearSolve
+    using BenchmarkTools: @ballocated
+    using StaticArrays: @SVector
+
+    @testset for (concrete_jac, linsolve) in (
+        (Val(false), KrylovJL_CG(; precs = nothing)),
+        (Val(false), KrylovJL_GMRES(; precs = nothing)),
+        (
+            Val(true),
+            KrylovJL_GMRES(;
+                    precs = (A,
+                    p = nothing) -> (
+                        Diagonal(randn!(similar(A, size(A, 1)))), LinearAlgebra.I
+                    )
+            ),
+        ),
+    )
+        @testset "[OOP] u0: $(typeof(u0))" for u0 in ([1.0, 1.0], @SVector[1.0, 1.0])
+            solver = NewtonRaphson(; forcing=EisenstatWalkerForcing2(), linsolve, concrete_jac)
+            sol = solve_oop(quadratic_f, u0; solver)
+            @test SciMLBase.successful_retcode(sol)
+            err = maximum(abs, quadratic_f(sol.u, 2.0))
+            @test err < 1e-9
+
+            cache = init(
+                NonlinearProblem{false}(quadratic_f, u0, 2.0), solver, abstol = 1e-9
+            )
+            @test (@ballocated solve!($cache)) < 200
+        end
+
+        @testset "[IIP] u0: $(typeof(u0))" for u0 in ([1.0, 1.0],)
+            solver = NewtonRaphson(; forcing=EisenstatWalkerForcing2(), linsolve, concrete_jac)
+
+            sol = solve_iip(quadratic_f!, u0; solver)
+            @test SciMLBase.successful_retcode(sol)
+            err = maximum(abs, quadratic_f(sol.u, 2.0))
+            @test err < 1e-9
+
+            cache = init(
+                NonlinearProblem{true}(quadratic_f!, u0, 2.0), solver, abstol = 1e-9
+            )
+            @test (@ballocated solve!($cache)) ≤ 64
+        end
+    end
+end
+
 @testitem "NewtonRaphson" setup=[CoreRootfindTesting] tags=[:core] begin
     using ADTypes, LineSearch, LinearAlgebra, Random, LinearSolve
     using LineSearches: LineSearches
@@ -12,7 +59,7 @@ end
     using Zygote, ForwardDiff, FiniteDiff
 
     # Conditionally import Enzyme only if not on Julia prerelease
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         using Enzyme
     end
 
@@ -20,7 +67,7 @@ end
 
     # Filter autodiff backends based on Julia version
     autodiff_backends=[AutoForwardDiff(), AutoZygote(), AutoFiniteDiff()]
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         push!(autodiff_backends, AutoEnzyme())
     end
 
@@ -110,7 +157,7 @@ end
     using Zygote, ForwardDiff, FiniteDiff
 
     # Conditionally import Enzyme only if not on Julia prerelease
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         using Enzyme
     end
 
@@ -121,7 +168,7 @@ end
 
     # Filter autodiff backends based on Julia version
     autodiff_backends=[AutoForwardDiff(), AutoZygote(), AutoFiniteDiff()]
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         push!(autodiff_backends, AutoEnzyme())
     end
 
@@ -207,7 +254,7 @@ end
     using Zygote, ForwardDiff, FiniteDiff
 
     # Conditionally import Enzyme only if not on Julia prerelease
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         using Enzyme
     end
 
@@ -219,7 +266,7 @@ end
 
     # Filter autodiff backends based on Julia version
     autodiff_backends=[AutoForwardDiff(), AutoZygote(), AutoFiniteDiff()]
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         push!(autodiff_backends, AutoEnzyme())
     end
 
@@ -340,13 +387,13 @@ end
     using Zygote, ForwardDiff, FiniteDiff
 
     # Conditionally import Enzyme only if not on Julia prerelease
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         using Enzyme
     end
 
     # Filter autodiff backends based on Julia version
     autodiff_backends=[AutoForwardDiff(), AutoZygote(), AutoFiniteDiff()]
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         push!(autodiff_backends, AutoEnzyme())
     end
 
@@ -451,7 +498,7 @@ end
 
     # Filter autodiff backends based on Julia version
     autodiff_backends=[AutoForwardDiff(), AutoFiniteDiff(), AutoZygote()]
-    if isempty(VERSION.prerelease)
+    if isempty(VERSION.prerelease) && VERSION < v"1.12"
         push!(autodiff_backends, AutoEnzyme())
     end
 
